@@ -20,6 +20,7 @@
  * This file is part of the gazelle-installer.
  ***************************************************************************/
 
+#include <utility>
 #include <sys/stat.h>
 #include <QDebug>
 #include <QMessageBox>
@@ -50,7 +51,7 @@ Oobe::Oobe(MProcess &mproc, Ui::MeInstall &ui, QWidget *parent, QSettings &appCo
             "-mindepth", "2", "-type", "f", "-printf", "%P\\n"}, nullptr, true);
     timeZones = proc.readOutLines();
     gui.comboTimeArea->clear();
-    for (const QString &zone : qAsConst(timeZones)) {
+    for (const QString &zone : std::as_const(timeZones)) {
         const QString &area = zone.section('/', 0, 0);
         if (gui.comboTimeArea->findData(QVariant(area)) < 0) {
             QString text(area);
@@ -147,8 +148,8 @@ void Oobe::manageConfig(MSettings &config, bool save) noexcept
     config.startGroup("Localization", gui.pageLocalization);
     config.manageComboBox("Locale", gui.comboLocale, true);
     config.manageCheckBox("LocalClock", gui.checkLocalClock);
-    const char *clockChoices[] = {"24", "12"};
-    QRadioButton *clockRadios[] = {gui.radioClock24, gui.radioClock12};
+    static constexpr const char *clockChoices[] = {"24", "12"};
+    QRadioButton *const clockRadios[] = {gui.radioClock24, gui.radioClock12};
     config.manageRadios("ClockHours", 2, clockChoices, clockRadios);
     if (save) {
         config.setValue("Timezone", gui.comboTimeZone->currentData().toString());
@@ -167,8 +168,8 @@ void Oobe::manageConfig(MSettings &config, bool save) noexcept
     config.manageCheckBox("Autologin", gui.checkAutoLogin);
     config.manageCheckBox("SaveDesktop", gui.checkSaveDesktop);
     if (online) gui.checkSaveDesktop->setCheckState(Qt::Unchecked);
-    const char *oldHomeActions[] = {"Use", "Save", "Delete"};
-    QRadioButton *oldHomeRadios[] = {gui.radioOldHomeUse, gui.radioOldHomeSave, gui.radioOldHomeDelete};
+    static constexpr const char *oldHomeActions[] = {"Use", "Save", "Delete"};
+    QRadioButton *const oldHomeRadios[] = {gui.radioOldHomeUse, gui.radioOldHomeSave, gui.radioOldHomeDelete};
     config.manageRadios("OldHomeAction", 3, oldHomeActions, oldHomeRadios);
     config.manageGroupCheckBox("EnableRoot", gui.boxRootAccount);
     if (!save || oem) { // Transfer default passwords under OEM mode.
@@ -705,7 +706,7 @@ void Oobe::timeAreaIndexChanged(int index) noexcept
     if (index < 0 || index >= gui.comboTimeArea->count()) return;
     const QString &area = gui.comboTimeArea->itemData(index).toString();
     gui.comboTimeZone->clear();
-    for (const QString &zone : qAsConst(timeZones)) {
+    for (const QString &zone : std::as_const(timeZones)) {
         if (zone.startsWith(area)) {
             QString text(QString(zone).section('/', 1));
             text.replace('_', ' ');
